﻿# Package ID of the package or Task Sequence in Configuration Manager
$packageID = "KR100907"
# Load the Software Center Object
$softwareCenter = New-Object -ComObject "UIResource.UIResourceMgr"
# A simple test to see if the specified Package ID indeed is deployed to the device
$testPackageID = Get-CimInstance -Namespace root\ccm\clientsdk -Query "SELECT * FROM CCM_Program where PackageID = '$packageID'"
# If the package/task sequence is deployed to the device
if (-NOT[string]::IsNullOrEmpty($testPackageID)) {
    $programID = $testPackageID.ProgramID
    $registryPath = "HKCU:\SOFTWARE\imab.dk\WaaS\2004"
    # Create registry path for detection method if it does not exist
    if (-NOT(Test-Path -Path $registryPath)) { New-Item -Path $registryPath –Force }
    # Install the package/task sequence and launch the Software Center into the OSD tab. Write successful detection method to registry
    try {
        $softwareCenter.ExecuteProgram($programID,$packageID,$true)
        if (Test-Path -Path "$env:windir\CCM\ClientUX\SCClient.exe") { Start-Process -FilePath "$env:windir\CCM\ClientUX\SCClient.exe" -ArgumentList "SoftwareCenter:Page=OSD" -WindowStyle Maximized }
        New-ItemProperty -Path $registryPath -Name "PSADT-TS-DetectionMethod" -Value 0 -PropertyType "String" -Force
    }
    # Write failed detection method to registry and exit PSADT with error code 1
    catch {
        New-ItemProperty -Path $registryPath -Name "PSADT-TS-DetectionMethod" -Value 1 -PropertyType "String" -Force 
        exit 1   
    }
}
# Else exit PSADT with error code 1
else {
    exit 1
}